@@ -5,7 +5,9 @@ use strict;
 use warnings;
 use Carp 'croak';
 
-our $VERSION = '0.02';
+our $VERSION = '0.04';
+
+use constant LINE_LENGTH => 451; # I wish they were using a modern file format.
 
 require XSLoader;
 XSLoader::load('Astro::Hipparcos', $VERSION);
@@ -19,15 +21,30 @@ sub new {
   my $self = bless {
     fh => $ifh,
     filename => $file,
+    filesize => (-s $file),
   } => $class;
   return $self;
 }
 
 sub get_record {
   my $self = shift;
+  my $recno = shift;
+  my $line;
+  local $/ = "\012"; # database uses unix newlines
   my $fh = $self->{fh};
-  my $line = <$fh>;
-  return if not defined $line;
+  if (not $recno) {
+    $line = <$fh>;
+    return if not defined $line;
+  }
+  else {
+    my $line_start = LINE_LENGTH*($recno-1);
+    my $line_end = $line_start+LINE_LENGTH;
+    return() if $line_end > $self->{filesize};
+    seek $fh, $line_start, 0
+      or die "Could not seek to pos '$line_start' of file '$self->{filename}': $!";
+    $line = <$fh>;
+    return if not defined $line;
+  }
   my $record = Astro::Hipparcos::Record->new();
   $record->ParseRecord($line);
   return $record;
@@ -47,6 +64,9 @@ Astro::Hipparcos - Perl extension for reading the Hipparcos star catalog
   while (defined(my $record = $catalog->get_record())) {
     print $record->get_HIP(), "\n"; # print record id
   }
+  
+  # the twelth record (i.e. first is 1, NOT 0)
+  my $specific_record = $catalog->get_record(12);
 
 =head1 DESCRIPTION
 
